@@ -6,6 +6,8 @@ use Eixo::Base::Clase;
 use JSON;
 use Data::UUID;
 
+use Eixo::Queue::JobCifrador;
+
 my $UUID_INSTANCE;
 
 BEGIN{
@@ -130,7 +132,13 @@ sub removeResult{
 
     delete($self->results->{$key});
 } 
+sub cifrar :Sig(self, s){
+    Eixo::Queue::JobCifrador->new->cifrar(@_);
+}
 
+sub descifrar :Sig(self, s, s){
+    Eixo::Queue::JobCifrador->new->descifrar(@_);
+}
 
 
 1;
